Package: scan
Type: Package
Title: Single-Case Data Analyses for Single and Multiple Baseline
        Designs
Version: 0.68.1
Date: 2026-04-27
Authors@R: c(
  person("Juergen", "Wilbert", email = "juergen.wilbert@uni-muenster.de", 
    role = c("cre", "aut"), comment = c(ORCID = "0000-0002-8392-2873")), 
  person("Timo", "Lueke", email = "timo.lueke@uni-graz.at", role = "aut", 
    comment = c(ORCID = "0000-0002-2603-7341")))
Depends: R (>= 4.1.0)
Imports: stats, nlme, MCMCglmm, utils, methods, graphics, car, gt,
        knitr, kableExtra, readxl, magrittr, miniUI, rstudioapi, rlang,
        cli
Suggests: testthat (>= 3.0.0), shiny, yaml, scplot
Description: A collection of procedures for analysing, visualising, 
  and managing single-case data. Multi-phase and multi-baseline designs are 
  supported. Analysing methods include regression models 
  (multilevel, multivariate, bayesian), between case standardised mean difference, 
  overlap indices ('PND', 'PEM', 'PAND', 'NAP', 'PET', 'tau-u', 'IRD', 'baseline corrected tau', 
  'CDC'), and randomization tests. Data preparation functions support outlier 
  detection, handling missing values, scaling, and custom transformations. 
  An export function helps to generate html, word, and latex tables in a 
  publication friendly style. A shiny app allows to use scan in a graphical 
  user interface.
  More details can be found in the online book 'Analyzing single-case data with 
  R and scan', Juergen Wilbert (2026)
  <https://jazznbass.github.io/scan-Book/>.
License: GPL (>= 3)
URL: https://github.com/jazznbass/scan/,
        https://jazznbass.github.io/scan-Book/,
        https://jazznbass.github.io/scan/
BugReports: https://github.com/jazznbass/scan/issues
LazyData: true
Encoding: UTF-8
RoxygenNote: 7.3.3
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-04-27 14:18:20 UTC; wilbert
Author: Juergen Wilbert [cre, aut] (ORCID:
    <https://orcid.org/0000-0002-8392-2873>),
  Timo Lueke [aut] (ORCID: <https://orcid.org/0000-0002-2603-7341>)
Maintainer: Juergen Wilbert <juergen.wilbert@uni-muenster.de>
Repository: CRAN
Date/Publication: 2026-04-28 05:10:02 UTC
Built: R 4.4.3; ; 2026-05-01 15:32:55 UTC; unix
