# Generated by roxygen2: do not edit by hand

S3method("$",scdf)
S3method("[",scdf)
S3method(anova,sc_hplm)
S3method(anova,sc_mplm)
S3method(anova,sc_plm)
S3method(as.data.frame,scdf)
S3method(c,scdf)
S3method(coef,sc_hplm)
S3method(coef,sc_plm)
S3method(export,sc_ac)
S3method(export,sc_bcsmd)
S3method(export,sc_bctau)
S3method(export,sc_bplm)
S3method(export,sc_cdc)
S3method(export,sc_desc)
S3method(export,sc_hplm)
S3method(export,sc_ird)
S3method(export,sc_mplm)
S3method(export,sc_nap)
S3method(export,sc_outlier)
S3method(export,sc_overlap)
S3method(export,sc_pand)
S3method(export,sc_pem)
S3method(export,sc_pet)
S3method(export,sc_plm)
S3method(export,sc_pnd)
S3method(export,sc_power)
S3method(export,sc_rand)
S3method(export,sc_smd)
S3method(export,sc_tauu)
S3method(export,sc_trend)
S3method(export,scdf)
S3method(export,scdf_summary)
S3method(fetch,sc_bplm)
S3method(fetch,sc_hplm)
S3method(fetch,sc_mplm)
S3method(fetch,sc_plm)
S3method(na.omit,scdf)
S3method(plot,scdf)
S3method(print,sc_ac)
S3method(print,sc_bcsmd)
S3method(print,sc_bctau)
S3method(print,sc_bplm)
S3method(print,sc_cdc)
S3method(print,sc_desc)
S3method(print,sc_design)
S3method(print,sc_hplm)
S3method(print,sc_ird)
S3method(print,sc_mplm)
S3method(print,sc_nap)
S3method(print,sc_outlier)
S3method(print,sc_overlap)
S3method(print,sc_pand)
S3method(print,sc_pem)
S3method(print,sc_pet)
S3method(print,sc_plm)
S3method(print,sc_pnd)
S3method(print,sc_power)
S3method(print,sc_rand)
S3method(print,sc_rci)
S3method(print,sc_smd)
S3method(print,sc_tauu)
S3method(print,sc_trend)
S3method(print,scdf)
S3method(subset,scdf)
S3method(summary,scdf)
S3method(transform,scdf)
export("%>%")
export("scdf_attr<-")
export(across_cases)
export(add_dummy_variables)
export(add_l2)
export(all_cases)
export(as_scdf)
export(autocorr)
export(batch_apply)
export(between_smd)
export(bplm)
export(cdc)
export(center_at)
export(combine)
export(convert)
export(corrected_tau)
export(describe)
export(design)
export(estimate_design)
export(export)
export(fetch)
export(fill_missing)
export(fillmissingSC)
export(first_of)
export(hplm)
export(import_scdf)
export(ird)
export(is.scdf)
export(local_regression)
export(moving_mean)
export(moving_median)
export(mplm)
export(nap)
export(outlier)
export(overlap)
export(overlapSC)
export(pand)
export(pem)
export(pet)
export(plm)
export(plotSC)
export(plot_rand)
export(pnd)
export(power_test)
export(power_testSC)
export(rSC)
export(rand.test)
export(randSC)
export(rand_test)
export(random_scdf)
export(ranks)
export(rci)
export(rciSC)
export(readSC)
export(readSC.excel)
export(read_scdf)
export(rescale)
export(rowwise)
export(sample_names)
export(scdf)
export(scdf_attr)
export(select_cases)
export(select_phases)
export(set_dvar)
export(set_mvar)
export(set_na_at)
export(set_pvar)
export(set_vars)
export(shift)
export(shinyscan)
export(smd)
export(smooth_cases)
export(standardize)
export(style_plot)
export(tauUSC)
export(tau_u)
export(trend)
export(truncate_phase)
export(writeSC)
export(write_scdf)
import(MCMCglmm)
import(graphics)
import(gt)
import(kableExtra)
import(knitr)
import(methods)
import(nlme)
import(stats)
importFrom(car,Anova)
importFrom(cli,col_blue)
importFrom(magrittr,"%>%")
importFrom(utils,capture.output)
importFrom(utils,combn)
importFrom(utils,install.packages)
importFrom(utils,read.csv)
