#' Pipe
#'
#' Several functions in scan are designed to work with pipes `\%>\%`. This
#' pipe function is directly imported from magrittr.
#'
#' @importFrom magrittr %>%
#' @details Since R 4.1 a pipe operator |> is included in base R. This pipe
#'   operator can be used along with scan perfectly fine.
#' @name %>%
#' @rdname pipe
#' @export
#' @keywords internal
NULL