#' Single-Case Data Analyses
#'
#' A collection of procedures for analysing, visualising, and managing
#' single-case data.
#'
#' @name scan-package
#' @aliases scan-package scan
#' @author Juergen Wilbert \[aut, cre\]
#' @keywords package
#' @import nlme
#' @import stats
#' @import graphics
#' @import knitr
#' @import kableExtra
#' @import methods
#' @import gt
#' @import MCMCglmm
#' @importFrom car Anova
#' @importFrom cli col_blue
#' @importFrom utils install.packages read.csv capture.output combn
#' @keywords internal
"_PACKAGE"



