% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/print.sc.R, R/print.sc_desc.R,
%   R/print.sc_design.R, R/print.sc_nap.R, R/print.sc_overlap.R,
%   R/print.sc_pem.R, R/print.sc_pet.R, R/print.sc_pnd.R, R/print.sc_power.R,
%   R/print.sc_rci.R, R/print.sc_smd.R, R/print.sc_trend.R
\name{print.sc}
\alias{print.sc}
\alias{print.sc_desc}
\alias{print.sc_design}
\alias{print.sc_nap}
\alias{print.sc_overlap}
\alias{print.sc_pem}
\alias{print.sc_pet}
\alias{print.sc_pnd}
\alias{print.sc_power}
\alias{print.sc_rci}
\alias{print.sc_smd}
\alias{print.sc_trend}
\title{Print methods for scan objects}
\usage{
\method{print}{sc_desc}(x, digits = "auto", ...)

\method{print}{sc_design}(x, ...)

\method{print}{sc_nap}(x, digits = "auto", nice = TRUE, complete = FALSE, ...)

\method{print}{sc_overlap}(x, digits = "auto", ...)

\method{print}{sc_pem}(x, ...)

\method{print}{sc_pet}(x, digits = 3, ...)

\method{print}{sc_pnd}(x, ...)

\method{print}{sc_power}(x, duration = FALSE, digits = 1, ...)

\method{print}{sc_rci}(x, digits = 3, ...)

\method{print}{sc_smd}(x, digits = "auto", ...)

\method{print}{sc_trend}(x, digits = 3, ...)
}
\arguments{
\item{x}{Object}

\item{digits}{The minimum number of significant digits to be use.
If set to "auto" (default), values are predefined.}

\item{...}{Further parameters passed to the print function}

\item{nice}{If set TRUE (default) output values are rounded and optimized for
publication tables.}

\item{duration}{If TRUE the duration for computation is printed.}
}
\description{
Print methods for scan objects
}
\keyword{internal}
