% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/importer-gadget.R
\name{import_scdf}
\alias{import_scdf}
\title{Import scdf – RStudio Addin}
\usage{
import_scdf()
}
\description{
Import scdf – RStudio Addin
}
